pyasge.KEYS
=====================

.. currentmodule:: pyasge.KEYS
.. autosummary::
   :toctree: _generate

.. autodata:: pyasge.KEYS
   :noindex:

Actions
########
.. autoattribute:: pyasge.KEYS.KEY_PRESSED
.. autoattribute:: pyasge.KEYS.KEY_RELEASED
.. autoattribute:: pyasge.KEYS.KEY_REPEATED

Modifiers
#########
.. autoattribute:: pyasge.KEYS.MOD_SHIFT
.. autoattribute:: pyasge.KEYS.MOD_CONTROL
.. autoattribute:: pyasge.KEYS.MOD_ALT
.. autoattribute:: pyasge.KEYS.MOD_SUPER
.. autoattribute:: pyasge.KEYS.MOD_CAPS_LOCK
.. autoattribute:: pyasge.KEYS.MOD_NUM_LOCK

Key Constants
#############
.. autoattribute:: pyasge.KEYS.KEY_SPACE
.. autoattribute:: pyasge.KEYS.KEY_APOSTROPHE
.. autoattribute:: pyasge.KEYS.KEY_COMMA
.. autoattribute:: pyasge.KEYS.KEY_MINUS
.. autoattribute:: pyasge.KEYS.KEY_PERIOD
.. autoattribute:: pyasge.KEYS.KEY_SLASH
.. autoattribute:: pyasge.KEYS.KEY_SEMICOLON
.. autoattribute:: pyasge.KEYS.KEY_EQUAL
.. autoattribute:: pyasge.KEYS.KEY_A
.. autoattribute:: pyasge.KEYS.KEY_B
.. autoattribute:: pyasge.KEYS.KEY_C
.. autoattribute:: pyasge.KEYS.KEY_D
.. autoattribute:: pyasge.KEYS.KEY_E
.. autoattribute:: pyasge.KEYS.KEY_F
.. autoattribute:: pyasge.KEYS.KEY_G
.. autoattribute:: pyasge.KEYS.KEY_H
.. autoattribute:: pyasge.KEYS.KEY_I
.. autoattribute:: pyasge.KEYS.KEY_J
.. autoattribute:: pyasge.KEYS.KEY_K
.. autoattribute:: pyasge.KEYS.KEY_L
.. autoattribute:: pyasge.KEYS.KEY_M
.. autoattribute:: pyasge.KEYS.KEY_N
.. autoattribute:: pyasge.KEYS.KEY_O
.. autoattribute:: pyasge.KEYS.KEY_P
.. autoattribute:: pyasge.KEYS.KEY_Q
.. autoattribute:: pyasge.KEYS.KEY_R
.. autoattribute:: pyasge.KEYS.KEY_S
.. autoattribute:: pyasge.KEYS.KEY_T
.. autoattribute:: pyasge.KEYS.KEY_U
.. autoattribute:: pyasge.KEYS.KEY_V
.. autoattribute:: pyasge.KEYS.KEY_W
.. autoattribute:: pyasge.KEYS.KEY_X
.. autoattribute:: pyasge.KEYS.KEY_Y
.. autoattribute:: pyasge.KEYS.KEY_Z
.. autoattribute:: pyasge.KEYS.KEY_LEFT_BRACKET
.. autoattribute:: pyasge.KEYS.KEY_BACKSLASH
.. autoattribute:: pyasge.KEYS.KEY_RIGHT_BRACKET
.. autoattribute:: pyasge.KEYS.KEY_GRAVE_ACCENT
.. autoattribute:: pyasge.KEYS.KEY_WORLD_1
.. autoattribute:: pyasge.KEYS.KEY_WORLD_2
.. autoattribute:: pyasge.KEYS.KEY_ESCAPE
.. autoattribute:: pyasge.KEYS.KEY_ENTER
.. autoattribute:: pyasge.KEYS.KEY_TAB
.. autoattribute:: pyasge.KEYS.KEY_BACKSPACE
.. autoattribute:: pyasge.KEYS.KEY_DELETE
.. autoattribute:: pyasge.KEYS.KEY_RIGHT
.. autoattribute:: pyasge.KEYS.KEY_LEFT
.. autoattribute:: pyasge.KEYS.KEY_DOWN
.. autoattribute:: pyasge.KEYS.KEY_UP
